==> kimageannotator_0.6.0.orig.tar.gz: kImageAnnotator-0.6.0/translations/kImageAnnotator_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>배열</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>맨 앞으로 가져오기</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>앞으로 가져오기</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>뒤로 보내기</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>맨 뒤로 보내기</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>이 항목 선택</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>붙여넣기</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>편집</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>일반 설정</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>그림 설정</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>색상</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>글자색</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>너비</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>숫자 시드</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>난독화 계수</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>항목 그림자</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>항목 설정</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>다른 모두 닫기</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>모두 닫기</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>왼쪽에 있는 모두 닫기</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>오른쪽에 있는 모두 닫기</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>도구 선택</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>사용함</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>사용 안 함</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>W:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>적용</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>경계선과 채우기 표시 여부</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>경계선과 채우기</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>경계선 있음, 채우기 없음</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>경계선 없음, 채우기 없음</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>글꼴 크기</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>굵게</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>이탤릭</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>밑줄</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>그림 효과</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>효과 없음</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>외부 그림자</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>회색조</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>경계선</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>색 반전</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>제한됨</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>이 옵션을 사용하면 캔버스에
배경 그림을 포함하도록 강제합니다.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>W:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>적용</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>색:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>캔버스 배경색</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>이미지 회전</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° 오른쪽</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° 왼쪽</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>임의</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>양수는 오른쪽, 음수는 왼쪽으로 회전합니다.
90°의 배수가 아닌 값으로 회전하면 품질 손실이 있을 수 있습니다.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>수평</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>수직</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>확인</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>회전</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>뒤집기</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>그림 크기 조정</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>가로 세로 비율 유지</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>너비:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>높이:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>확인</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>픽셀</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>백분율</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>스티커</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>선택</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>펜</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>숫자</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>마커 직사각형</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>마커 타원형</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>마커 펜</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>텍스트</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>화살표</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>이중 화살표</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>직선</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>흐리게</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>직사각형</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>타원형</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>숫자 포인터</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>스티커</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>픽셀화</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>텍스트 포인터</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>텍스트 화살표</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>숫자 화살표</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>복제</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>확대(%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>축소(%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>배율 초기화(%1)</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.7.2.orig.tar.gz: kImageAnnotator-0.7.2/translations/kImageAnnotator_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>배열</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>맨 앞으로 가져오기</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>앞으로 가져오기</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>뒤로 보내기</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>맨 뒤로 보내기</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>이 항목 선택</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>붙여넣기</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>편집</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation>제어</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>일반 설정</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>그림 설정</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>색상</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>글자색</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>너비</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>숫자 시드</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>난독화 계수</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>항목 그림자</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>항목 설정</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>규모</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>불투명</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>닫기</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>다른 모두 닫기</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>모두 닫기</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>왼쪽에 있는 모두 닫기</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>오른쪽에 있는 모두 닫기</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>도구 선택</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>사용함</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>사용 안 함</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation>실행 취소</translation>
    </message>
    <message>
        <source>Redo</source>
        <translation>다시 실행</translation>
    </message>
    <message>
        <source>Crop</source>
        <translation>자르기</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation>규모</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished">회전</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation>캔버스 수정</translation>
    </message>
    <message>
        <source>Cut</source>
        <translation>자르기</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>W:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>적용</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation type="unfinished">수직</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished">수평</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">적용</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">취소</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>경계선과 채우기 표시 여부</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>경계선과 채우기</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>경계선 있음, 채우기 없음</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>경계선 없음, 채우기 없음</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>글꼴 크기</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>굵게</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>이탤릭</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>밑줄</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>그림 효과</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>효과 없음</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>외부 그림자</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>회색조</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>경계선</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>색 반전</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>제한됨</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>활성화되면 캔버스를 적용합니다.
배경 이미지를 포함합니다.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>W:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>H:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>적용</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>색:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>캔버스 배경색</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>이미지 회전</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° 오른쪽</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° 왼쪽</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>임의</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>양수는 오른쪽, 음수는 왼쪽으로 회전합니다.
90°의 배수가 아닌 값으로 회전하면 품질 손실이 있을 수 있습니다.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>수평</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>수직</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>확인</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>회전</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>뒤집기</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>그림 크기 조정</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>가로 세로 비율 유지</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>너비:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>높이:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>확인</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>픽셀</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>백분율</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>스티커</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>선택</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>펜</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>숫자</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>마커 직사각형</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>마커 타원형</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>마커 펜</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>텍스트</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>화살표</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>이중 화살표</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>직선</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>흐리게</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>직사각형</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>타원형</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>숫자 포인터</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>스티커</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>픽셀화</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>텍스트 포인터</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>텍스트 화살표</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>숫자 화살표</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>복제</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>확대(%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>축소(%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>배율 초기화(%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation>확대/축소 재설정</translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation>좋은 이미지</translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
